<?php

namespace Realestate\Lead\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Realestate\Lead\Interfaces\LeadRepositoryInterface;

class LeadPublicController extends BaseController
{
    // use LeadWorkflow;

    /**
     * Constructor.
     *
     * @param type \Realestate\Lead\Interfaces\LeadRepositoryInterface $lead
     *
     * @return type
     */
    public function __construct(LeadRepositoryInterface $lead)
    {
        $this->repository = $lead;
        parent::__construct();
    }

    /**
     * Show lead's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $leads = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$lead::$lead.names'))
            ->view('$lead::public.lead.index')
            ->data(compact('$leads'))
            ->output();
    }

    /**
     * Show lead's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $leads = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$lead::$lead.names'))
            ->view('$lead::public.lead.index')
            ->data(compact('$leads'))
            ->output();
    }

    /**
     * Show lead.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $lead = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$lead->name . trans('$lead::$lead.name'))
            ->view('$lead::public.lead.show')
            ->data(compact('$lead'))
            ->output();
    }

}
